@@ -9,6 +9,8 @@ from django.db.models import Q
 
 from django.utils.translation import ugettext_lazy, ugettext as _
 
+import datetime, time, pytz, calendar
+
 def clone(modeladmin, request, queryset):
     for o in queryset:
         o.clone()
@@ -75,6 +77,11 @@ class RecordingJobAdmin(admin.ModelAdmin):
             clone,
     ]
 
+    def launch_now(self, request, queryset):
+        d = datetime.datetime.fromtimestamp(time.time(), pytz.UTC)
+        queryset.update(status="waiting",scheduled_start_date=d)
+    launch_now.short_description=_("Launch now")
+
     def wait(self, request, queryset):
         queryset.update(status="waiting")
     wait.short_description=_("Set to waiting")
